@@ -28,12 +28,10 @@ use autodie;
 use List::MoreUtils qw(any);
 use List::Util qw(first none);
 use Path::Tiny;
-use Unicode::UTF8 qw(valid_utf8 decode_utf8);
 
 use Lintian::Data ();
 use Lintian::Deb822Parser qw(parse_dpkg_control_string);
 use Lintian::Relation ();
-use Lintian::Util qw(rstrip strip);
 
 use Moo;
 use namespace::clean;
@@ -78,14 +76,13 @@ sub source {
       unless $dcontrol->is_open_ok;
 
     # check that control is UTF-8 encoded
-    my $bytes = path($dcontrol->unpacked_path)->slurp;
-    unless (valid_utf8($bytes)) {
+    unless ($dcontrol->is_valid_utf8) {
 
         $self->tag('debian-control-file-uses-obsolete-national-encoding');
         return;
     }
 
-    my $contents = decode_utf8($bytes);
+    my $contents = $dcontrol->decoded_utf8;
     my @lines = split(/\n/, $contents);
 
     # Nag about dh_make Vcs comment only once
@@ -458,18 +455,6 @@ sub source {
         }
     }
 
-    # find binary packages that Pre-Depend on multiarch-support without going
-    # via ${misc:Pre-Depends}
-    if ($processable->source_field('build-depends')) {
-        for my $bin (@package_names) {
-            my $raw = $processable->binary_field($bin, 'pre-depends');
-            next unless $raw;
-            if($raw =~ /multiarch-support/) {
-                $self->tag('pre-depends-directly-on-multiarch-support',$bin);
-            }
-        }
-    }
-
     # Make sure that the Architecture field in source packages is not multiline
     for my $bin (@package_names) {
         # The Architecture field is mandatory and dpkg-buildpackage
@@ -545,7 +530,9 @@ sub check_dev_depends {
 
     my $processable = $self->processable;
 
-    strip($depends);
+    # trim both ends
+    $depends =~ s/^\s+|\s+$//g;
+
     for my $target (@packages) {
         next
           unless ($target =~ /^lib[\w.+-]+\d/
@@ -631,7 +618,8 @@ sub check_relation {
     ) {
         my ($prev, $next) = ($1, $2);
         for ($prev, $next) {
-            rstrip;
+            # trim right
+            s/\s+$//;
         }
         $self->tag('missing-separator-between-items',
             'in', $pkg,"$field field between '$prev' and '$next'");
