@@ -45,7 +45,7 @@ use Lintian::Internal::FrontendUtil
 use Lintian::Output::Standard;
 use Lintian::Pool;
 use Lintian::Profile;
-use Lintian::Util qw(strip safe_qx);
+use Lintian::Util qw(safe_qx);
 
 # only in GNOME; need original environment
 my $interactive = -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));
@@ -437,7 +437,10 @@ sub cfg_display_level {
         }
 
         return if @display_level;
-        strip($val);
+
+        # trim both ends
+        $val =~ s/^\s+|\s+$//g;
+
         foreach my $dl (split m/\s++/, $val) {
             record_display_level('display-level', $dl);
         }
@@ -540,24 +543,6 @@ my %opthash = (
     'exp-output:s' => \$experimental_output_opts,
 );
 
-# dplint has a similar wrapper; but it uses a different exit code
-# for uncaught exceptions (compared to what lintian documents).
-sub _main {
-    eval {_main();};
-    # Cocerce the error to a string
-    if (my $err = "$@") {
-        $err =~ s/\n//;
-        # Special-case the message from the signal handler as it is not
-        # entirely unexpected.
-        if ($err eq 'N: Interrupted') {
-            fatal_error($err);
-        }
-        print STDERR "$err\n";
-        fatal_error('Uncaught exception');
-    }
-    fatal_error('Assertion error: _main returned !?');
-}
-
 sub main {
 
     $0 = join(' ', $0, @ARGV);
@@ -566,7 +551,7 @@ sub main {
     STDOUT->autoflush;
     STDERR->autoflush;
 
-    binmode(STDOUT, ':encoding(UTF-8)');
+    # layers are additive; STDOUT already had UTF-8 from frontend/dplint
     binmode(STDERR, ':encoding(UTF-8)');
 
     # Globally ignore SIGPIPE.  We'd rather deal with error returns from write
